import axios from 'axios'
import { ElMessage, ElMessageBox } from 'element-plus'
import router from '../router'
import { API_BASE_URL } from '../config/api.config'

const request = axios.create({
  baseURL: API_BASE_URL,
  timeout: 10000,
  headers: {
    'Content-Type': 'application/json'
  }
})

// 请求拦截器
request.interceptors.request.use(
  config => {
    // 如果是访客页面的请求，不需要添加 token
    if (!config.url.startsWith('/visitor')) {
      const token = localStorage.getItem('token')
      if (token) {
        const tokenData = JSON.parse(token)
        config.headers.Authorization = `Bearer ${tokenData.token}`
      }
    }
    return config
  },
  error => {
    return Promise.reject(error)
  }
)

// 响应拦截器
request.interceptors.response.use(
  response => {
    const { data } = response
    console.log('Response Data:', data)
    
    if (data.retcode === 0) {
      return data
    }

    // 显示错误消息
    ElMessage.error(data.message || '操作失败')
    return Promise.reject(new Error(data.message || '操作失败'))
  },
  error => {
    console.error('Request Error:', error)
    
    if (error.response) {
      switch (error.response.status) {
        case 401:
          // 只有非访客页面才需要清除登录状态并跳转
          if (!router.currentRoute.value.path.startsWith('/visitor')) {
            localStorage.removeItem('token')
            localStorage.removeItem('userRole')
            router.push('/login')
          }
          break
        case 403:
          ElMessage.error('没有权限访问')
          break
        default:
          ElMessage.error(error.response.data?.message || '请求失败')
      }
    } else if (error.request) {
      ElMessage.error('服务器无响应，请检查后端服务是否启动')
    } else {
      ElMessage.error('请求配置错误')
    }
    return Promise.reject(error)
  }
)

export default request 